/*
 * Copyright 2016 University of Chicago
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file command.c
 * Implementation of the s3 DSI command
 */
#include "globus_gridftp_server_s3_base.h"

/**
 * @brief command
 * @details
 * This interface function is called when the client sends a 'command'.
 * commands are such things as mkdir, remdir, delete.  The complete
 * enumeration is below.
 *
 * To determine which command is being requested look at cmd_info->command.
 * Possible values are:
 *      GLOBUS_GFS_CMD_MKD = 1,
 *      GLOBUS_GFS_CMD_RMD,
 *      GLOBUS_GFS_CMD_DELE,
 *      GLOBUS_GFS_CMD_RNTO,
 *      GLOBUS_GFS_CMD_RNFR,
 *      GLOBUS_GFS_CMD_CKSM,
 *      GLOBUS_GFS_CMD_SITE_CHMOD,
 *      GLOBUS_GFS_CMD_SITE_DSI
 */
void
globus_i_s3_command(
    globus_gfs_operation_t              op,
    globus_gfs_command_info_t          *cmd_info,
    void                               *user_arg)
{
    GlobusS3Enter();
    switch (cmd_info->command)
    {
        case GLOBUS_GFS_CMD_MKD:
            globus_i_s3_mkdir(op, cmd_info, user_arg);
            break;
        case GLOBUS_GFS_CMD_RMD:
            globus_i_s3_rmdir(op, cmd_info, user_arg);
            break;
        case GLOBUS_GFS_CMD_DELE:
            globus_i_s3_delete(op, cmd_info, user_arg);
            break;
        case GLOBUS_GFS_CMD_RNTO:
            globus_i_s3_rename(op, cmd_info, user_arg);
            break;
        case GLOBUS_GFS_CMD_CKSM:
            globus_i_s3_checksum(op, cmd_info, user_arg);
            break;
        default:
            globus_gridftp_server_finished_command(op, GLOBUS_FAILURE, NULL);
    }
    GlobusS3Exit();
}
/* globus_i_s3_command() */
// vim: ft=c:
